@@ -25,38 +25,34 @@ class AssignUsersRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'CCC', '2020-07-01', 'AssignUsers')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_RamIdList(self):
+	def get_RamIdList(self): # String
 		return self.get_query_params().get('RamIdList')
 
-	def set_RamIdList(self,RamIdList):
-		self.add_query_param('RamIdList',RamIdList)
-
-	def get_RoleId(self):
+	def set_RamIdList(self, RamIdList):  # String
+		self.add_query_param('RamIdList', RamIdList)
+	def get_RoleId(self): # String
 		return self.get_query_params().get('RoleId')
 
-	def set_RoleId(self,RoleId):
-		self.add_query_param('RoleId',RoleId)
-
-	def get_WorkMode(self):
+	def set_RoleId(self, RoleId):  # String
+		self.add_query_param('RoleId', RoleId)
+	def get_WorkMode(self): # String
 		return self.get_query_params().get('WorkMode')
 
-	def set_WorkMode(self,WorkMode):
-		self.add_query_param('WorkMode',WorkMode)
-
-	def get_InstanceId(self):
+	def set_WorkMode(self, WorkMode):  # String
+		self.add_query_param('WorkMode', WorkMode)
+	def get_InstanceId(self): # String
 		return self.get_query_params().get('InstanceId')
 
-	def set_InstanceId(self,InstanceId):
-		self.add_query_param('InstanceId',InstanceId)
-
-	def get_SkillLevelList(self):
+	def set_InstanceId(self, InstanceId):  # String
+		self.add_query_param('InstanceId', InstanceId)
+	def get_SkillLevelList(self): # String
 		return self.get_query_params().get('SkillLevelList')
 
-	def set_SkillLevelList(self,SkillLevelList):
-		self.add_query_param('SkillLevelList',SkillLevelList)
\ No newline at end of file
+	def set_SkillLevelList(self, SkillLevelList):  # String
+		self.add_query_param('SkillLevelList', SkillLevelList)
