@@ -25,20 +25,19 @@ class ListSipTracesRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'CCC', '2020-07-01', 'ListSipTraces')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_CallId(self):
+	def get_CallId(self): # String
 		return self.get_query_params().get('CallId')
 
-	def set_CallId(self,CallId):
-		self.add_query_param('CallId',CallId)
-
-	def get_InstanceId(self):
+	def set_CallId(self, CallId):  # String
+		self.add_query_param('CallId', CallId)
+	def get_InstanceId(self): # String
 		return self.get_query_params().get('InstanceId')
 
-	def set_InstanceId(self,InstanceId):
-		self.add_query_param('InstanceId',InstanceId)
\ No newline at end of file
+	def set_InstanceId(self, InstanceId):  # String
+		self.add_query_param('InstanceId', InstanceId)
