@@ -25,38 +25,39 @@ class ModifyUserRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'CCC', '2020-07-01', 'ModifyUser')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_RoleId(self):
+	def get_RoleId(self): # String
 		return self.get_query_params().get('RoleId')
 
-	def set_RoleId(self,RoleId):
-		self.add_query_param('RoleId',RoleId)
-
-	def get_Mobile(self):
+	def set_RoleId(self, RoleId):  # String
+		self.add_query_param('RoleId', RoleId)
+	def get_Mobile(self): # String
 		return self.get_query_params().get('Mobile')
 
-	def set_Mobile(self,Mobile):
-		self.add_query_param('Mobile',Mobile)
-
-	def get_WorkMode(self):
+	def set_Mobile(self, Mobile):  # String
+		self.add_query_param('Mobile', Mobile)
+	def get_WorkMode(self): # String
 		return self.get_query_params().get('WorkMode')
 
-	def set_WorkMode(self,WorkMode):
-		self.add_query_param('WorkMode',WorkMode)
-
-	def get_UserId(self):
+	def set_WorkMode(self, WorkMode):  # String
+		self.add_query_param('WorkMode', WorkMode)
+	def get_UserId(self): # String
 		return self.get_query_params().get('UserId')
 
-	def set_UserId(self,UserId):
-		self.add_query_param('UserId',UserId)
-
-	def get_InstanceId(self):
+	def set_UserId(self, UserId):  # String
+		self.add_query_param('UserId', UserId)
+	def get_InstanceId(self): # String
 		return self.get_query_params().get('InstanceId')
 
-	def set_InstanceId(self,InstanceId):
-		self.add_query_param('InstanceId',InstanceId)
\ No newline at end of file
+	def set_InstanceId(self, InstanceId):  # String
+		self.add_query_param('InstanceId', InstanceId)
+	def get_DisplayId(self): # String
+		return self.get_query_params().get('DisplayId')
+
+	def set_DisplayId(self, DisplayId):  # String
+		self.add_query_param('DisplayId', DisplayId)
