@@ -25,20 +25,24 @@ class RemovePhoneNumbersRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'CCC', '2020-07-01', 'RemovePhoneNumbers')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_NumberList(self):
+	def get_NumberList(self): # String
 		return self.get_query_params().get('NumberList')
 
-	def set_NumberList(self,NumberList):
-		self.add_query_param('NumberList',NumberList)
-
-	def get_InstanceId(self):
+	def set_NumberList(self, NumberList):  # String
+		self.add_query_param('NumberList', NumberList)
+	def get_InstanceId(self): # String
 		return self.get_query_params().get('InstanceId')
 
-	def set_InstanceId(self,InstanceId):
-		self.add_query_param('InstanceId',InstanceId)
\ No newline at end of file
+	def set_InstanceId(self, InstanceId):  # String
+		self.add_query_param('InstanceId', InstanceId)
+	def get_Force(self): # Boolean
+		return self.get_query_params().get('Force')
+
+	def set_Force(self, Force):  # Boolean
+		self.add_query_param('Force', Force)
