@@ -25,20 +25,19 @@ class RemoveUsersRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'CCC', '2020-07-01', 'RemoveUsers')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_UserIdList(self):
+	def get_UserIdList(self): # String
 		return self.get_query_params().get('UserIdList')
 
-	def set_UserIdList(self,UserIdList):
-		self.add_query_param('UserIdList',UserIdList)
-
-	def get_InstanceId(self):
+	def set_UserIdList(self, UserIdList):  # String
+		self.add_query_param('UserIdList', UserIdList)
+	def get_InstanceId(self): # String
 		return self.get_query_params().get('InstanceId')
 
-	def set_InstanceId(self,InstanceId):
-		self.add_query_param('InstanceId',InstanceId)
\ No newline at end of file
+	def set_InstanceId(self, InstanceId):  # String
+		self.add_query_param('InstanceId', InstanceId)
