@@ -25,50 +25,44 @@ class StartBack2BackCallRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'CCC', '2020-07-01', 'StartBack2BackCall')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_Callee(self):
+	def get_Callee(self): # String
 		return self.get_query_params().get('Callee')
 
-	def set_Callee(self,Callee):
-		self.add_query_param('Callee',Callee)
-
-	def get_Broker(self):
+	def set_Callee(self, Callee):  # String
+		self.add_query_param('Callee', Callee)
+	def get_Broker(self): # String
 		return self.get_query_params().get('Broker')
 
-	def set_Broker(self,Broker):
-		self.add_query_param('Broker',Broker)
-
-	def get_AdditionalBroker(self):
+	def set_Broker(self, Broker):  # String
+		self.add_query_param('Broker', Broker)
+	def get_AdditionalBroker(self): # String
 		return self.get_query_params().get('AdditionalBroker')
 
-	def set_AdditionalBroker(self,AdditionalBroker):
-		self.add_query_param('AdditionalBroker',AdditionalBroker)
-
-	def get_Tags(self):
+	def set_AdditionalBroker(self, AdditionalBroker):  # String
+		self.add_query_param('AdditionalBroker', AdditionalBroker)
+	def get_Tags(self): # String
 		return self.get_query_params().get('Tags')
 
-	def set_Tags(self,Tags):
-		self.add_query_param('Tags',Tags)
-
-	def get_TimeoutSeconds(self):
+	def set_Tags(self, Tags):  # String
+		self.add_query_param('Tags', Tags)
+	def get_TimeoutSeconds(self): # Integer
 		return self.get_query_params().get('TimeoutSeconds')
 
-	def set_TimeoutSeconds(self,TimeoutSeconds):
-		self.add_query_param('TimeoutSeconds',TimeoutSeconds)
-
-	def get_Caller(self):
+	def set_TimeoutSeconds(self, TimeoutSeconds):  # Integer
+		self.add_query_param('TimeoutSeconds', TimeoutSeconds)
+	def get_Caller(self): # String
 		return self.get_query_params().get('Caller')
 
-	def set_Caller(self,Caller):
-		self.add_query_param('Caller',Caller)
-
-	def get_InstanceId(self):
+	def set_Caller(self, Caller):  # String
+		self.add_query_param('Caller', Caller)
+	def get_InstanceId(self): # String
 		return self.get_query_params().get('InstanceId')
 
-	def set_InstanceId(self,InstanceId):
-		self.add_query_param('InstanceId',InstanceId)
\ No newline at end of file
+	def set_InstanceId(self, InstanceId):  # String
+		self.add_query_param('InstanceId', InstanceId)
